<?php
/**
 * @file
 * Drupal Field Hidden module administration
 */

/**
 * Helper for field_hidden_help(), which implements hook_help().
 *
 * @param string $path
 * @param unknown $arg
 *   - default: NULL
 * @return string|void
 */
function _field_hidden_help($path, $arg = NULL) {
  switch ($path) {
    case 'admin/help#field_hidden':
      return '<h3>' . t('About') . '</h3>'
          . '<p>' . t('The Field Hidden module defines five hidden field types - text, long text, integer, decimal, and floating-point.', array('@field-help' => url('admin/help/field')))
          . '</p>'
          . '<h5>' . t('Hidden field types reflect data types') . '</h5>'
          . '<p>' . t('The only difference between text and long text is the database data type used - varchar versus text (MySQL: longtext).')
          . '<br/>' . t('Neither allow HTML nor PHP, only plain text.')
          . '</p>'
          . '<p>' . t('The numeric types correspond to the data types integer, decimal and float.')
          . '<br/>' . t('Decimal is often the better choice when it comes to decimal/floating numbers because it usually allows for a higher number of precise digits (typically 14) than float/double database fields do.')
          . '</p>'
          . '<h5>' . t('Hidden - in what sense?') . '</h5>'
          . '<p>' . t('A hidden field will always be hidden when editing a node/entity - an &lt;input type=&quot;hidden&quot; /&gt; form element.')
          . '<br/>' . t('When a node/entity is displayed on a page, these hidden fields default to be fully hidden (kept out the page\'s HTML output entirely).')
          . '<br/>' . t('The value of a hidden field may however be displayed in output, if another format than &lt;Hidden&gt; is selected in the content type\'s \'@manage_display\' section.', array('@manage_display' => t('Manage Display')))
          . '</p>';
  }
}

/**
 * Defines configuration form fields.
 *
 * Implements drupal_get_form().
 *
 * @param array $form
 * @param array &$form_state
 * @return array
 *   - the return value of system_settings_form()
 */
function _field_hidden_admin_form($form, &$form_state) {
  $form['field_hidden_instance_settings_display_defval'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display default value field in instance setting form'),
    '#decription' => t('Otherwise controlling/setting the default value in the field instance setting dialogue gets kind of hard.'),
    '#default_value' => variable_get('field_hidden_instance_settings_display_defval', TRUE), // Yep, default to do it.
    '#required' => FALSE,
  );
  return system_settings_form($form);
}